@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.15'
+__version__ = '0.5.18'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -18,28 +18,35 @@ __version__ = '0.5.15'
 from PySide.QtGui import QMainWindow, QHBoxLayout, QSizePolicy, QToolButton, \
     QVBoxLayout, QFileDialog, QDesktopServices, QScrollArea, QPushButton, \
     QToolBar, QLabel, QWidget, QInputDialog, QMenu, QAction, QApplication, \
-    QIcon, QMessageBox, QPlainTextEdit
+    QIcon, QMessageBox, QPlainTextEdit, QTextCursor
 from PySide.QtCore import Qt, QUrl, QSettings, Slot, Signal, QTimer
-from PySide.QtMaemo5 import *
+
+try:
+    from PySide.QtMaemo5 import *
+except:
+    pass
+
+try:
+    import osso
+except:
+    pass
+
 from qbadgebutton import QToolBadgeButton
 
-import dbus
-import dbus.service
+
+
 import os
 import sys
-import pickle
-import time
 from list_view import KhweetsView
 from list_model import KhweetsModel, ISMEROLE, IDROLE, ORIGINROLE, SCREENNAMEROLE, PROTECTEDROLE, USERIDROLE
-from settings import KhweeteurPref
-from dbusobj import KhweeteurDBus
-import re
+
+import dbus.service
 
 try:
     from QtMobility.Location import QGeoPositionInfoSource
 except:
     print 'Pyside QtMobility not installed or broken'
-    
+
 class KhweeteurDBusHandler(dbus.service.Object):
 
     def __init__(self, parent):
@@ -54,7 +61,10 @@ class KhweeteurDBusHandler(dbus.service.Object):
 
     @dbus.service.signal(dbus_interface='net.khertan.Khweeteur')
     def require_update(self, optional=None):
-        self.parent.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        try:
+            self.parent.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
+        except:
+            pass
 
     def post_tweet(
         self,
@@ -67,7 +77,8 @@ class KhweeteurDBusHandler(dbus.service.Object):
         action='',
         tweet_id='0',
         ):
-
+        import time
+        import pickle
         if not os.path.exists(self.post_path):
             os.makedirs(self.post_path)
         with open(os.path.join(self.post_path, str(time.time())), 'wb') as \
@@ -101,7 +112,11 @@ class KhweeteurAbout(QMainWindow):
         except:
             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
 
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        try:
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        except:
+            pass
+
         self.setWindowTitle(self.tr('Khweeteur About'))
 
         try:
@@ -210,6 +225,11 @@ class Khweeteur(QApplication):
         self.setOrganizationName('Khertan Software')
         self.setOrganizationDomain('khertan.net')
         self.setApplicationName('Khweeteur')
+
+        try:
+            self.osso_c = osso.Context('net.khertan.khweeteur', "0.0.1", False)
+        except:
+            pass
         self.run()
 
     def check_crash_report(self):
@@ -277,15 +297,18 @@ class KhweeteurWin(QMainWindow):
     def __init__(self, parent=None):
         QMainWindow.__init__(self, parent)
 
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        try:
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        except:
+            pass
         self.setWindowTitle('Khweeteur')
 
-        self.listen_dbus()
-
         settings = QSettings()
 
         self.view = KhweetsView()
+        self.setCentralWidget(self.view)
+
         self.model = KhweetsModel()
         try:
             self.model.setLimit(int(settings.value('tweetHistory')))
@@ -294,8 +317,6 @@ class KhweeteurWin(QMainWindow):
         self.view.setModel(self.model)
         self.view.clicked.connect(self.switch_tb_action)
 
-        self.dbus_handler.require_update()
-
         self.toolbar = QToolBar('Toolbar')
         self.addToolBar(Qt.BottomToolBarArea, self.toolbar)
 
@@ -312,51 +333,10 @@ class KhweeteurWin(QMainWindow):
         self.toolbar.addAction(self.tb_new)
         self.list_tb_action.append(self.tb_new)
 
-        # Back button (Edit + Action)
-
-        self.tb_back = QAction(QIcon.fromTheme('general_back'), 'Back', self)
-        self.tb_back.triggered.connect(self.switch_tb_default)
-        self.toolbar.addAction(self.tb_back)
-        self.edit_tb_action.append(self.tb_back)
-        self.action_tb_action.append(self.tb_back)
-
-        self.setupMenu()
-
-        # Twitpic button
-
-        self.tb_twitpic = QAction(QIcon.fromTheme('tasklaunch_images'),
-                                  'Twitpic', self)
-        self.tb_twitpic.triggered.connect(self.do_tb_twitpic)
-        self.toolbar.addAction(self.tb_twitpic)
-        self.edit_tb_action.append(self.tb_twitpic)
-
-        # Text field (edit)
-
-        self.tb_text = QPlainTextEdit()
-        self.tb_text_reply_id = 0
-        self.tb_text_reply_base_url = ''
-        self.tb_text.setFixedHeight(66)
-        self.edit_tb_action.append(self.toolbar.addWidget(self.tb_text))
-
-        # Char count (Edit)
-
-        self.tb_charCounter = QLabel('140')
-        self.edit_tb_action.append(self.toolbar.addWidget(self.tb_charCounter))
-        self.tb_text.textChanged.connect(self.countCharsAndResize)
-
-        # Send tweet (Edit)
-
-        self.tb_send = QAction(QIcon.fromTheme('khweeteur'), 'Tweet', self)
-        self.tb_send.triggered.connect(self.do_tb_send)
-        self.tb_send.setVisible(False)
-        self.toolbar.addAction(self.tb_send)
-        self.edit_tb_action.append(self.tb_send)
-
         # Refresh (Default)
 
         self.tb_update = QAction(QIcon.fromTheme('general_refresh'), 'Update',
                                  self)
-        self.tb_update.triggered.connect(self.dbus_handler.require_update)
         self.toolbar.addAction(self.tb_update)
         self.list_tb_action.append(self.tb_update)
 
@@ -388,7 +368,6 @@ class KhweeteurWin(QMainWindow):
         # Search Button
 
         self.tb_search_menu = QMenu()
-        self.loadSearchMenu()
 
         # Search (Default)
 
@@ -404,7 +383,6 @@ class KhweeteurWin(QMainWindow):
         # Lists Button
 
         self.tb_list_menu = QMenu()
-        self.loadListMenu()
 
         # Lists (Default)
 
@@ -425,58 +403,6 @@ class KhweeteurWin(QMainWindow):
         self.toolbar.addAction(self.tb_fullscreen)
         self.list_tb_action.append(self.tb_fullscreen)
 
-        # Reply button (Action)
-
-        self.tb_reply = QAction('Reply', self)
-        self.tb_reply.setShortcut('Ctrl+M')
-        self.toolbar.addAction(self.tb_reply)
-        self.tb_reply.triggered.connect(self.do_tb_reply)
-        self.action_tb_action.append(self.tb_reply)
-
-        # Retweet (Action)
-
-        self.tb_retweet = QAction('Retweet', self)
-        self.tb_retweet.setShortcut('Ctrl+P')
-        self.toolbar.addAction(self.tb_retweet)
-        self.tb_retweet.triggered.connect(self.do_tb_retweet)
-        self.action_tb_action.append(self.tb_retweet)
-
-        # Follow (Action)
-
-        self.tb_follow = QAction('Follow', self)
-        self.tb_follow.triggered.connect(self.do_tb_follow)
-        self.toolbar.addAction(self.tb_follow)
-        self.action_tb_action.append(self.tb_follow)
-
-        # UnFollow (Action)
-
-        self.tb_unfollow = QAction('Unfollow', self)
-        self.tb_unfollow.triggered.connect(self.do_tb_unfollow)
-        self.toolbar.addAction(self.tb_unfollow)
-        self.action_tb_action.append(self.tb_unfollow)
-
-        # Favorite (Action)
-
-        self.tb_favorite = QAction('Favorite', self)
-        self.tb_favorite.triggered.connect(self.do_tb_favorite)
-        self.toolbar.addAction(self.tb_favorite)
-        self.action_tb_action.append(self.tb_favorite)
-
-        # Open URLs (Action)
-
-        self.tb_urls = QAction('Open URLs', self)
-        self.tb_urls.setShortcut('Ctrl+O')
-        self.toolbar.addAction(self.tb_urls)
-        self.tb_urls.triggered.connect(self.do_tb_openurl)
-        self.action_tb_action.append(self.tb_urls)
-
-        # Delete (Action)
-
-        self.tb_delete = QAction('Delete', self)
-        self.toolbar.addAction(self.tb_delete)
-        self.tb_delete.triggered.connect(self.do_tb_delete)
-        self.action_tb_action.append(self.tb_delete)
-
         # Actions not in toolbar
 
         self.tb_scrolltop = QAction('Scroll to top', self)
@@ -504,17 +430,129 @@ class KhweeteurWin(QMainWindow):
         self.tb_copy.triggered.connect(self.do_tb_copy)
         self.addAction(self.tb_copy)
 
-        self.switch_tb_default()
+#        self.switch_tb_default()
 
         self.setWindowTitle('Khweeteur : Home')
-        self.setCentralWidget(self.view)
-        QTimer.singleShot(100,self.post_init)
+        self.model.load('HomeTimeline')
+        self.show()
+        QTimer.singleShot(500,self.post_init)
 
     @Slot()
     def post_init(self):
-        self.model.load('HomeTimeline')
+        self.listen_dbus()
+        self.dbus_handler.require_update()
+        self.tb_update.triggered.connect(self.dbus_handler.require_update)
         self.geolocDoStart()
 
+        self.loadSearchMenu()
+        self.loadListMenu()
+
+        #Toolbar to set after startup
+        # Back button (Edit + Action)
+
+        self.tb_back = QAction(QIcon.fromTheme('general_back'), 'Back', self)
+        self.tb_back.triggered.connect(self.switch_tb_default)
+        self.toolbar.addAction(self.tb_back)
+        self.tb_back.setVisible(False)
+        self.edit_tb_action.append(self.tb_back)
+        self.action_tb_action.append(self.tb_back)
+
+        self.setupMenu()
+
+        # Twitpic button
+
+        self.tb_twitpic = QAction(QIcon.fromTheme('tasklaunch_images'),
+                                  'Twitpic', self)
+        self.tb_twitpic.triggered.connect(self.do_tb_twitpic)
+        self.tb_twitpic.setVisible(False)
+        self.toolbar.addAction(self.tb_twitpic)
+        self.edit_tb_action.append(self.tb_twitpic)
+
+        # Text field (edit)
+
+        self.tb_text = QPlainTextEdit()
+        self.tb_text_reply_id = 0
+        self.tb_text_reply_base_url = ''
+        self.tb_text.setFixedHeight(66)
+        action = self.toolbar.addWidget(self.tb_text)
+        action.setVisible(False)
+        self.edit_tb_action.append(action)
+
+        # Char count (Edit)
+
+        self.tb_charCounter = QLabel('140')
+        action = self.toolbar.addWidget(self.tb_charCounter)
+        action.setVisible(False)
+        self.edit_tb_action.append(action)
+        self.tb_text.textChanged.connect(self.countCharsAndResize)
+
+        # Send tweet (Edit)
+
+        self.tb_send = QAction(QIcon.fromTheme('khweeteur'), 'Tweet', self)
+        self.tb_send.triggered.connect(self.do_tb_send)
+        self.tb_send.setVisible(False)
+        self.toolbar.addAction(self.tb_send)
+        self.edit_tb_action.append(self.tb_send)
+
+        # Reply button (Action)
+
+        self.tb_reply = QAction('Reply', self)
+        self.tb_reply.setShortcut('Ctrl+M')
+        self.tb_reply.setVisible(False)
+        self.toolbar.addAction(self.tb_reply)
+        self.tb_reply.triggered.connect(self.do_tb_reply)
+        self.action_tb_action.append(self.tb_reply)
+
+        # Retweet (Action)
+
+        self.tb_retweet = QAction('Retweet', self)
+        self.tb_retweet.setShortcut('Ctrl+P')
+        self.tb_retweet.setVisible(False)
+        self.toolbar.addAction(self.tb_retweet)
+        self.tb_retweet.triggered.connect(self.do_tb_retweet)
+        self.action_tb_action.append(self.tb_retweet)
+
+        # Follow (Action)
+
+        self.tb_follow = QAction('Follow', self)
+        self.tb_follow.triggered.connect(self.do_tb_follow)
+        self.tb_follow.setVisible(False)
+        self.toolbar.addAction(self.tb_follow)
+        self.action_tb_action.append(self.tb_follow)
+
+        # UnFollow (Action)
+
+        self.tb_unfollow = QAction('Unfollow', self)
+        self.tb_unfollow.triggered.connect(self.do_tb_unfollow)
+        self.tb_unfollow.setVisible(False)
+        self.toolbar.addAction(self.tb_unfollow)
+        self.action_tb_action.append(self.tb_unfollow)
+
+        # Favorite (Action)
+
+        self.tb_favorite = QAction('Favorite', self)
+        self.tb_favorite.triggered.connect(self.do_tb_favorite)
+        self.tb_favorite.setVisible(False)
+        self.toolbar.addAction(self.tb_favorite)
+        self.action_tb_action.append(self.tb_favorite)
+
+        # Open URLs (Action)
+
+        self.tb_urls = QAction('Open URLs', self)
+        self.tb_urls.setShortcut('Ctrl+O')
+        self.tb_urls.setVisible(False)
+        self.toolbar.addAction(self.tb_urls)
+        self.tb_urls.triggered.connect(self.do_tb_openurl)
+        self.action_tb_action.append(self.tb_urls)
+
+        # Delete (Action)
+
+        self.tb_delete = QAction('Delete', self)
+        self.tb_delete.setVisible(False)
+        self.toolbar.addAction(self.tb_delete)
+        self.tb_delete.triggered.connect(self.do_tb_delete)
+        self.action_tb_action.append(self.tb_delete)
+
     @Slot()
     def do_tb_fullscreen(self):
         if self.isFullScreen():
@@ -540,6 +578,9 @@ class KhweeteurWin(QMainWindow):
         self.model.refreshTimestamp()
 
     def listen_dbus(self):
+        import dbus
+        import dbus.service
+        from dbusobj import KhweeteurDBus
         from dbus.mainloop.qt import DBusQtMainLoop
         self.dbus_loop = DBusQtMainLoop()
         dbus.set_default_main_loop(self.dbus_loop)
@@ -702,8 +743,8 @@ class KhweeteurWin(QMainWindow):
                 0,
                 1,
                 text,
-                ('' if self.geoloc_source == None else self.geoloc_source[0]),
-                ('' if self.geoloc_source == None else self.geoloc_source[1]),
+                ('' if self.geoloc_source == None else self.geoloc_coordinates[0]),
+                ('' if self.geoloc_source == None else self.geoloc_coordinates[1]),
                 filename,
                 'twitpic',
                 '',
@@ -713,6 +754,7 @@ class KhweeteurWin(QMainWindow):
 
     @Slot()
     def do_tb_openurl(self):
+        import re
         for index in self.view.selectedIndexes():
             status = self.model.data(index)
             try:
@@ -753,8 +795,10 @@ class KhweeteurWin(QMainWindow):
             tweet_source = self.model.data(index, role=ORIGINROLE)
             tweet_screenname = self.model.data(index, role=SCREENNAMEROLE)
         if tweet_id:
-            self.tb_text.setPlainText('@' + tweet_screenname
-                                      + self.tb_text.toPlainText())
+            self.tb_text.setPlainText('@%s ' % tweet_screenname)
+            cur = self.tb_text.textCursor()
+            cur.movePosition(QTextCursor.End, QTextCursor.MoveAnchor)
+            self.tb_text.setTextCursor(cur)
             self.tb_text_reply_id = tweet_id
             self.tb_text_reply_base_url = tweet_source
             self.switch_tb_edit()
@@ -995,14 +1039,14 @@ class KhweeteurWin(QMainWindow):
 #        local_self.setFixedHeight(min(370, text_height + (fr.height() - cr.height()) + 6))
 #        local_self.updateGeometry()
 #Resize
-#        doc = self.document()            
+#        doc = self.document()
         s = doc.size().toSize()
         s.setHeight((s.height() + 1) * (fm.lineSpacing()+1))
         fr = local_self.frameRect()
         cr = local_self.contentsRect()
         local_self.setFixedHeight(min(s.height() +  (fr.height() - cr.height() - 1) - 15,370))
         local_self.updateGeometry()
-        
+
     def loadSearchMenu(self):
         settings = QSettings()
         self.tb_search_menu.clear()
@@ -1085,6 +1129,7 @@ class KhweeteurWin(QMainWindow):
 
     @Slot()
     def showPrefs(self):
+        from settings import KhweeteurPref
         khtsettings = KhweeteurPref(parent=self)
         khtsettings.save.connect(self.refreshPrefs)
         khtsettings.show()
