@@ -86,6 +86,11 @@ class OAuthView(QWebView):
         res = regex.findall(self.page().mainFrame().toHtml())
         if len(res) > 0:
             self.pin = res[0]
+        else:
+            regex = re.compile('.*<code>(.*)</code>')
+            res = regex.findall(self.page().mainFrame().toHtml())
+            if len(res) > 0:
+                self.pin = res[0]
 
         self.loggedIn = self.pin not in (None, '')
 
@@ -197,8 +202,11 @@ class KhweeteurPref(QMainWindow):
 
         self.settings = QSettings()
 
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        try:
+            self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+            self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        except:
+            pass
         self.setAttribute(Qt.WA_DeleteOnClose, True)
         self.setWindowTitle('Khweeteur Prefs')
 
@@ -268,11 +276,15 @@ class KhweeteurPref(QMainWindow):
             self.history_value.setValue(60)
 
         if self.settings.contains('useGPS'):
-            self.useGPS_value.setCheckState(Qt.CheckState(int(self.settings.value('useGPS'
-                    ))))
+            self.useGPS_value.setCheckState(Qt.CheckState(int(self.settings.value('useGPS'))))
         else:
             self.useGPS_value.setCheckState(Qt.CheckState(2))
 
+        if self.settings.contains('useGPSOnDemand'):
+            self.useGPSOnDemand_value.setCheckState(Qt.CheckState(int(self.settings.value('useGPSOnDemand'))))
+        else:
+            self.useGPSOnDemand_value.setCheckState(Qt.CheckState(2))
+
         if self.settings.contains('showInfos'):
             self.showInfos_value.setCheckState(Qt.CheckState(int(self.settings.value('showInfos'
                     ))))
@@ -302,6 +314,7 @@ class KhweeteurPref(QMainWindow):
         self.settings.setValue('useBitly', self.useBitly_value.checkState())
         self.settings.setValue('theme', self.theme_value.currentText())
         self.settings.setValue('useGPS', self.useGPS_value.checkState())
+        self.settings.setValue('useGPSOnDemand', self.useGPSOnDemand_value.checkState())
         self.settings.setValue('showInfos', self.showInfos_value.checkState())
         self.settings.setValue('tweetHistory', self.history_value.value())
         self.settings.sync()
@@ -397,8 +410,11 @@ class KhweeteurPref(QMainWindow):
             self.oauth_webview.gotpin.connect(self.do_verify_pin)
             self.oauth_win = QMainWindow(self)
             self.oauth_win.setCentralWidget(self.oauth_webview)
-            self.oauth_win.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-            self.oauth_win.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+            try:
+                self.oauth_win.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+                self.oauth_win.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+            except:
+                pass
             self.oauth_win.setWindowTitle('Khweeteur OAuth')
             self.oauth_win.show()
         except httplib2.ServerNotFoundError, err:
@@ -481,8 +497,11 @@ class KhweeteurPref(QMainWindow):
         self.useGPS_value = QCheckBox(self.tr('Use GPS Geopositionning'))
         self._umain_layout.addWidget(self.useGPS_value, 13, 1)
 
+        self.useGPSOnDemand_value = QCheckBox(self.tr('Use GPS On Demand'))
+        self._umain_layout.addWidget(self.useGPSOnDemand_value, 14, 1)
+
         self.showInfos_value = QCheckBox(self.tr('Show errors notifications'))
-        self._umain_layout.addWidget(self.showInfos_value, 14, 1)
+        self._umain_layout.addWidget(self.showInfos_value, 15, 1)
 
         self._main_layout.addLayout(self._umain_layout)
 
