@@ -21,7 +21,7 @@ from settings import SUPPORTED_ACCOUNTS
 import pickle
 import re
 
-__version__ = '0.5.10'
+__version__ = '0.5.18'
 
 import dbus
 
@@ -41,8 +41,12 @@ except:
 import os.path
 import dbus.service
 
-# A hook to catch errors
+try:
+    from QtMobility.Location import QGeoPositionInfoSource
+except:
+    print 'Pyside QtMobility not installed or broken'
 
+# A hook to catch errors
 
 def install_excepthook(version):
     '''Install an excepthook called at each unexcepted error'''
@@ -154,9 +158,7 @@ class Daemon:
         """
         Start the daemon
         """
-
         # Check for a pidfile to see if the daemon already runs
-
         try:
             pf = file(self.pidfile, 'r')
             pid = int(pf.read().strip())
@@ -311,13 +313,24 @@ class KhweeteurDBusHandler(dbus.service.Object):
 class KhweeteurDaemon(Daemon):
 
     def run(self):
+        try:
+            from PySide import __version_info__ as __pyside_version__
+        except:
+            __pyside_version__ = None
+        try:
+            from PySide.QtCore import __version_info__ as __qt_version__
+        except:
+            __qt_version__ = None
+
         app = QCoreApplication(sys.argv)
 
         logging.basicConfig(level=logging.DEBUG,
                             format='%(asctime)s %(levelname)-8s %(message)s',
                             datefmt='%a, %d %b %Y %H:%M:%S',
-                            filename='/home/user/.khweeteur.log', filemode='w')
+                            filename=os.path.expanduser('~/.khweeteur.log'), filemode='w')
         logging.info('Starting daemon %s' % __version__)
+        logging.info('PySide version %s' % repr(__pyside_version__))
+        logging.info('Qt Version %s' % repr(__qt_version__))
         self.bus = dbus.SessionBus()
         self.bus.add_signal_receiver(self.update, path='/net/khertan/Khweeteur'
                                      , dbus_interface='net.khertan.Khweeteur',
@@ -331,6 +344,10 @@ class KhweeteurDaemon(Daemon):
         self.apis = {}
         self.idtag = None
 
+        #On demand geoloc
+        self.geoloc_source = None
+        self.geoloc_coordinates = None
+
         # Cache Folder
 
         self.cache_path = os.path.join(os.path.expanduser('~'), '.khweeteur',
@@ -367,6 +384,7 @@ class KhweeteurDaemon(Daemon):
 
         logging.debug('Timer added')
         app.exec_()
+        logging.debug('Daemon stop')
 
     def post_tweet(
         self,
@@ -413,9 +431,45 @@ class KhweeteurDaemon(Daemon):
 
         return api
 
+    def geolocStart(self):
+        '''Start the GPS with a 50000 refresh_rate'''
+        self.geoloc_coordinates = None
+        if self.geoloc_source is None:
+            try:
+                self.geoloc_source = \
+                    QGeoPositionInfoSource.createDefaultSource(None)
+            except:
+                self.geoloc_source = None
+                self.geoloc_coordinates = (0,0)
+                print 'PySide QtMobility not installed or package broken'
+            if self.geoloc_source is not None:
+                self.geoloc_source.setUpdateInterval(50000)
+                self.geoloc_source.positionUpdated.connect(self.geolocUpdated)
+                self.geoloc_source.startUpdates()
+
+    def geolocStop(self):
+        '''Stop the GPS'''
+
+        self.geoloc_coordinates = None
+        if self.geoloc_source is not None:
+            self.geoloc_source.stopUpdates()
+            self.geoloc_source = None
+
+    def geolocUpdated(self, update):
+        '''GPS Callback on update'''
+
+        if update.isValid():
+            self.geoloc_coordinates = (update.coordinate().latitude(),
+                                       update.coordinate().longitude())
+            self.geolocStop()
+            self.update()
+        else:
+            print 'GPS Update not valid'
+
     def do_posts(self):
         settings = QSettings('Khertan Software', 'Khweeteur')
         accounts = []
+
         nb_accounts = settings.beginReadArray('accounts')
         for index in range(nb_accounts):
             settings.setArrayIndex(index)
@@ -425,7 +479,16 @@ class KhweeteurDaemon(Daemon):
 
         logging.debug('Number of account : %s' % len(accounts))
 
-        for item in glob.glob(os.path.join(self.post_path, '*')):
+        items = glob.glob(os.path.join(self.post_path, '*'))
+
+        if len(items)>0:
+            if (settings.value('useGPS')=='2') and (settings.value('useGPSOnDemand')=='2'):
+                if self.geoloc_source == None:
+                    self.geolocStart()
+                if self.geoloc_coordinates == None:
+                    return
+
+        for item in items:
             logging.debug('Try to post %s' % (item, ))
             try:
                 with open(item, 'rb') as fhandle:
@@ -444,6 +507,11 @@ class KhweeteurDaemon(Daemon):
                                     text = text.replace(url, short_url)
                                 except:
                                     pass
+
+                    if (settings.value('useGPS')=='2') and (settings.value('useGPSOnDemand')=='2'):
+                        post['lattitude'], post['longitude'] = \
+                            self.geoloc_coordinates
+
                     if not post['lattitude']:
                         post['lattitude'] = None
                     else:
@@ -800,7 +868,10 @@ class KhweeteurDaemon(Daemon):
 
 if __name__ == '__main__':
     install_excepthook(__version__)
-    daemon = KhweeteurDaemon('/var/run/khweeteurd/khweeteurd.pid')
+    if os.path.exists('/var/run/khweeteurd'):
+        daemon = KhweeteurDaemon('/var/run/khweeteurd/khweeteurd.pid')
+    else:
+        daemon = KhweeteurDaemon('/tmp/khweeteurd.pid')
     if len(sys.argv) == 2:
         if 'startfromprefs' == sys.argv[1]:
             daemon.startfromprefs()
